# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._operations import Operations
from ._workspaces_operations import WorkspacesOperations
from ._private_endpoint_connections_operations import PrivateEndpointConnectionsOperations
from ._private_link_resources_operations import PrivateLinkResourcesOperations
from ._scaling_plans_operations import ScalingPlansOperations
from ._scaling_plan_pooled_schedules_operations import ScalingPlanPooledSchedulesOperations
from ._scaling_plan_personal_schedules_operations import ScalingPlanPersonalSchedulesOperations
from ._application_groups_operations import ApplicationGroupsOperations
from ._start_menu_items_operations import StartMenuItemsOperations
from ._applications_operations import ApplicationsOperations
from ._desktops_operations import DesktopsOperations
from ._host_pools_operations import HostPoolsOperations
from ._user_sessions_operations import UserSessionsOperations
from ._session_hosts_operations import SessionHostsOperations
from ._msix_packages_operations import MSIXPackagesOperations
from ._app_attach_package_info_operations import AppAttachPackageInfoOperations
from ._msix_images_operations import MsixImagesOperations
from ._app_attach_package_operations import AppAttachPackageOperations

from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "WorkspacesOperations",
    "PrivateEndpointConnectionsOperations",
    "PrivateLinkResourcesOperations",
    "ScalingPlansOperations",
    "ScalingPlanPooledSchedulesOperations",
    "ScalingPlanPersonalSchedulesOperations",
    "ApplicationGroupsOperations",
    "StartMenuItemsOperations",
    "ApplicationsOperations",
    "DesktopsOperations",
    "HostPoolsOperations",
    "UserSessionsOperations",
    "SessionHostsOperations",
    "MSIXPackagesOperations",
    "AppAttachPackageInfoOperations",
    "MsixImagesOperations",
    "AppAttachPackageOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.billing.aio import BillingManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer
from devtools_testutils.aio import recorded_by_proxy_async

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestBillingManagementSavingsPlansOperationsAsync(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(BillingManagementClient, is_async=True)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_list_by_savings_plan_order(self, resource_group):
        response = self.client.savings_plans.list_by_savings_plan_order(
            billing_account_name="str",
            savings_plan_order_id="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_list_by_billing_account(self, resource_group):
        response = self.client.savings_plans.list_by_billing_account(
            billing_account_name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_get_by_billing_account(self, resource_group):
        response = await self.client.savings_plans.get_by_billing_account(
            billing_account_name="str",
            savings_plan_order_id="str",
            savings_plan_id="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_begin_update_by_billing_account(self, resource_group):
        response = await (
            await self.client.savings_plans.begin_update_by_billing_account(
                billing_account_name="str",
                savings_plan_order_id="str",
                savings_plan_id="str",
                body={
                    "properties": {
                        "appliedScopeProperties": {
                            "displayName": "str",
                            "managementGroupId": "str",
                            "resourceGroupId": "str",
                            "subscriptionId": "str",
                            "tenantId": "str",
                        },
                        "appliedScopeType": "str",
                        "displayName": "str",
                        "renew": False,
                        "renewProperties": {
                            "purchaseProperties": {
                                "appliedScopeProperties": {
                                    "displayName": "str",
                                    "managementGroupId": "str",
                                    "resourceGroupId": "str",
                                    "subscriptionId": "str",
                                    "tenantId": "str",
                                },
                                "appliedScopeType": "str",
                                "billingPlan": "str",
                                "billingScopeId": "str",
                                "commitment": {"amount": 0.0, "currencyCode": "str", "grain": "str"},
                                "displayName": "str",
                                "renew": False,
                                "sku": {"name": "str"},
                                "term": "str",
                            }
                        },
                    },
                    "sku": {"name": "str"},
                    "tags": {"str": "str"},
                },
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_validate_update_by_billing_account(self, resource_group):
        response = await self.client.savings_plans.validate_update_by_billing_account(
            billing_account_name="str",
            savings_plan_order_id="str",
            savings_plan_id="str",
            body={
                "benefits": [
                    {
                        "appliedScopeProperties": {
                            "displayName": "str",
                            "managementGroupId": "str",
                            "resourceGroupId": "str",
                            "subscriptionId": "str",
                            "tenantId": "str",
                        },
                        "appliedScopeType": "str",
                        "displayName": "str",
                        "renew": False,
                        "renewProperties": {
                            "purchaseProperties": {
                                "appliedScopeProperties": {
                                    "displayName": "str",
                                    "managementGroupId": "str",
                                    "resourceGroupId": "str",
                                    "subscriptionId": "str",
                                    "tenantId": "str",
                                },
                                "appliedScopeType": "str",
                                "billingPlan": "str",
                                "billingScopeId": "str",
                                "commitment": {"amount": 0.0, "currencyCode": "str", "grain": "str"},
                                "displayName": "str",
                                "renew": False,
                                "sku": {"name": "str"},
                                "term": "str",
                            }
                        },
                    }
                ]
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: sample_delete_images.py

DESCRIPTION:
    This sample demonstrates deleting all but the most recent three images for each repository.

USAGE:
    python sample_delete_images.py

    Set the environment variables with your own values before running the sample:
    1) CONTAINERREGISTRY_ENDPOINT - The URL of your Container Registry account

    This sample assumes your registry has at least one repository with more than three images,
    run load_registry() if you don't have.
    Set the environment variables with your own values before running load_registry():
    1) CONTAINERREGISTRY_ENDPOINT - The URL of your Container Registry account
    2) CONTAINERREGISTRY_TENANT_ID - The service principal's tenant ID
    3) CONTAINERREGISTRY_CLIENT_ID - The service principal's client ID
    4) CONTAINERREGISTRY_CLIENT_SECRET - The service principal's client secret
"""
import os
from dotenv import find_dotenv, load_dotenv
from azure.containerregistry import ContainerRegistryClient, ArtifactManifestOrder
from utilities import load_registry, get_authority, get_credential


class DeleteImages(object):
    def __init__(self):
        load_dotenv(find_dotenv())
        self.endpoint = os.environ["CONTAINERREGISTRY_ENDPOINT"]
        self.authority = get_authority(self.endpoint)
        self.credential = get_credential(self.authority)

    def delete_images(self):
        load_registry(self.endpoint)
        # Instantiate an instance of ContainerRegistryClient
        # [START delete_manifests]
        with ContainerRegistryClient(self.endpoint, self.credential) as client:
            for repository in client.list_repository_names():
                # Keep the three most recent images, delete everything else
                manifest_count = 0
                for manifest in client.list_manifest_properties(
                    repository, order_by=ArtifactManifestOrder.LAST_UPDATED_ON_DESCENDING
                ):
                    manifest_count += 1
                    if manifest_count > 3:
                        # Make sure will have the permission to delete the manifest later
                        client.update_manifest_properties(repository, manifest.digest, can_write=True, can_delete=True)
                        print(f"Deleting {repository}:{manifest.digest}")
                        client.delete_manifest(repository, manifest.digest)
        # [END delete_manifests]


if __name__ == "__main__":
    sample = DeleteImages()
    sample.delete_images()



# The MIT License (MIT)
# Copyright (c) Microsoft Corporation. All rights reserved.

import unittest
import uuid

import pytest

import test_config
from azure.cosmos import PartitionKey
from azure.cosmos.aio import CosmosClient
from azure.cosmos.http_constants import HttpHeaders


# TODO: add more tests in this file once we have response headers in control plane operations
# TODO: add query tests once those changes are available

@pytest.mark.cosmosEmulator
class TestCosmosResponsesAsync(unittest.IsolatedAsyncioTestCase):
    """Python Cosmos Responses Tests.
    """

    configs = test_config.TestConfig
    host = configs.host
    masterKey = configs.masterKey
    TEST_DATABASE_ID = configs.TEST_DATABASE_ID

    @classmethod
    def setUpClass(cls):
        if (cls.masterKey == '[YOUR_KEY_HERE]' or
                cls.host == '[YOUR_ENDPOINT_HERE]'):
            raise Exception(
                "You must specify your Azure Cosmos account values for "
                "'masterKey' and 'host' at the top of this class to run the "
                "tests.")

    async def asyncSetUp(self):
        self.client = CosmosClient(self.host, self.masterKey)
        self.test_database = self.client.get_database_client(self.TEST_DATABASE_ID)

    async def asyncTearDown(self):
        await self.client.close()

    async def test_point_operation_headers_async(self):
        container = await self.test_database.create_container(id="responses_test" + str(uuid.uuid4()),
                                                              partition_key=PartitionKey(path="/company"))
        first_response = await container.upsert_item({"id": str(uuid.uuid4()), "company": "Microsoft"})
        lsn = first_response.get_response_headers()['lsn']

        create_response = await container.create_item({"id": str(uuid.uuid4()), "company": "Microsoft"})
        assert len(create_response.get_response_headers()) > 0
        assert int(lsn) + 1 == int(create_response.get_response_headers()['lsn'])
        lsn = create_response.get_response_headers()['lsn']

        read_response = await container.read_item(create_response['id'], create_response['company'])
        assert len(read_response.get_response_headers()) > 0

        upsert_response = await container.upsert_item({"id": str(uuid.uuid4()), "company": "Microsoft"})
        assert len(upsert_response.get_response_headers()) > 0
        assert int(lsn) + 1 == int(upsert_response.get_response_headers()['lsn'])
        lsn = upsert_response.get_response_headers()['lsn']

        upsert_response['replace'] = True
        replace_response = await container.replace_item(upsert_response['id'], upsert_response)
        assert replace_response['replace'] is not None
        assert len(replace_response.get_response_headers()) > 0
        assert int(lsn) + 1 == int(replace_response.get_response_headers()['lsn'])

        batch = []
        for i in range(50):
            batch.append(("create", ({"id": "item" + str(i), "company": "Microsoft"},)))
        batch_response = await container.execute_item_batch(batch_operations=batch, partition_key="Microsoft")
        assert len(batch_response.get_response_headers()) > 0
        assert int(lsn) + 1 < int(batch_response.get_response_headers()['lsn'])


if __name__ == '__main__':
    unittest.main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MetricSpecificationV1(Model):
    """Metric specification version 1.

    :param name: Name of the metric.
    :type name: str
    :param display_name: Display name of the metric.
    :type display_name: str
    :param display_description: Description of the metric to be displayed.
    :type display_description: str
    :param unit: Metric units. Possible values include: 'NotSpecified',
     'Percent', 'Count', 'Seconds', 'Milliseconds', 'Bytes', 'BytesPerSecond',
     'CountPerSecond'
    :type unit: str or ~azure.mgmt.edgegateway.models.MetricUnit
    :param aggregation_type: Metric aggregation type. Possible values include:
     'NotSpecified', 'None', 'Average', 'Minimum', 'Maximum', 'Total', 'Count'
    :type aggregation_type: str or
     ~azure.mgmt.edgegateway.models.MetricAggregationType
    :param dimensions: Metric dimensions, other than default dimension which
     is resource.
    :type dimensions: list[~azure.mgmt.edgegateway.models.MetricDimensionV1]
    :param fill_gap_with_zero: Set true to fill the gaps with zero.
    :type fill_gap_with_zero: bool
    :param category: Metric category. Possible values include: 'Capacity',
     'Transaction'
    :type category: str or ~azure.mgmt.edgegateway.models.MetricCategory
    :param resource_id_dimension_name_override: Resource name override.
    :type resource_id_dimension_name_override: str
    :param supported_time_grain_types: Support granularity of metrics.
    :type supported_time_grain_types: list[str or
     ~azure.mgmt.edgegateway.models.TimeGrain]
    :param supported_aggregation_types: Support metric aggregation type.
    :type supported_aggregation_types: list[str or
     ~azure.mgmt.edgegateway.models.MetricAggregationType]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'display_description': {'key': 'displayDescription', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'str'},
        'aggregation_type': {'key': 'aggregationType', 'type': 'str'},
        'dimensions': {'key': 'dimensions', 'type': '[MetricDimensionV1]'},
        'fill_gap_with_zero': {'key': 'fillGapWithZero', 'type': 'bool'},
        'category': {'key': 'category', 'type': 'str'},
        'resource_id_dimension_name_override': {'key': 'resourceIdDimensionNameOverride', 'type': 'str'},
        'supported_time_grain_types': {'key': 'supportedTimeGrainTypes', 'type': '[str]'},
        'supported_aggregation_types': {'key': 'supportedAggregationTypes', 'type': '[str]'},
    }

    def __init__(self, *, name: str=None, display_name: str=None, display_description: str=None, unit=None, aggregation_type=None, dimensions=None, fill_gap_with_zero: bool=None, category=None, resource_id_dimension_name_override: str=None, supported_time_grain_types=None, supported_aggregation_types=None, **kwargs) -> None:
        super(MetricSpecificationV1, self).__init__(**kwargs)
        self.name = name
        self.display_name = display_name
        self.display_description = display_description
        self.unit = unit
        self.aggregation_type = aggregation_type
        self.dimensions = dimensions
        self.fill_gap_with_zero = fill_gap_with_zero
        self.category = category
        self.resource_id_dimension_name_override = resource_id_dimension_name_override
        self.supported_time_grain_types = supported_time_grain_types
        self.supported_aggregation_types = supported_aggregation_types



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, TYPE_CHECKING

from azure.core import PipelineClient
from azure.core.rest import HttpRequest, HttpResponse

from ._configuration import AzureCommunicationEmailServiceConfiguration
from ._serialization import Deserializer, Serializer
from .operations import EmailOperations

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from typing import Dict


class AzureCommunicationEmailService:  # pylint: disable=client-accepts-api-version-keyword
    """Azure Communication Email Service.

    :ivar email: EmailOperations operations
    :vartype email: azure.communication.email.operations.EmailOperations
    :param endpoint: The communication resource, for example
     https://my-resource.communication.azure.com. Required.
    :type endpoint: str
    :keyword api_version: Api Version. Default value is "2024-07-01-preview". Note that overriding
     this default value may result in unsupported behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(  # pylint: disable=missing-client-constructor-parameter-credential
        self, endpoint: str, **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        self._config = AzureCommunicationEmailServiceConfiguration(endpoint=endpoint, **kwargs)
        self._client = PipelineClient(base_url=_endpoint, config=self._config, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.email = EmailOperations(self._client, self._config, self._serialize, self._deserialize)

    def send_request(self, request: HttpRequest, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.endpoint", self._config.endpoint, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, **kwargs)

    def close(self):
        # type: () -> None
        self._client.close()

    def __enter__(self):
        # type: () -> AzureCommunicationEmailService
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details):
        # type: (Any) -> None
        self._client.__exit__(*exc_details)



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.billing import BillingManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestBillingManagementPoliciesOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(BillingManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_by_customer(self, resource_group):
        response = self.client.policies.get_by_customer(
            billing_account_name="str",
            billing_profile_name="str",
            customer_name="str",
            policy_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_or_update_by_customer(self, resource_group):
        response = self.client.policies.begin_create_or_update_by_customer(
            billing_account_name="str",
            billing_profile_name="str",
            customer_name="str",
            parameters={
                "id": "str",
                "name": "str",
                "properties": {
                    "viewCharges": "str",
                    "policies": [{"name": "str", "policyType": "str", "scope": "str", "value": "str"}],
                    "provisioningState": "str",
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2024-04-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_by_billing_profile(self, resource_group):
        response = self.client.policies.get_by_billing_profile(
            billing_account_name="str",
            billing_profile_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_or_update_by_billing_profile(self, resource_group):
        response = self.client.policies.begin_create_or_update_by_billing_profile(
            billing_account_name="str",
            billing_profile_name="str",
            parameters={
                "id": "str",
                "name": "str",
                "properties": {
                    "enterpriseAgreementPolicies": {
                        "accountOwnerViewCharges": "str",
                        "authenticationType": "str",
                        "departmentAdminViewCharges": "str",
                    },
                    "invoiceSectionLabelManagement": "str",
                    "marketplacePurchases": "str",
                    "policies": [{"name": "str", "policyType": "str", "scope": "str", "value": "str"}],
                    "provisioningState": "str",
                    "reservationPurchases": "str",
                    "savingsPlanPurchases": "str",
                    "viewCharges": "str",
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2024-04-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_by_customer_at_billing_account(self, resource_group):
        response = self.client.policies.get_by_customer_at_billing_account(
            billing_account_name="str",
            customer_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_or_update_by_customer_at_billing_account(self, resource_group):
        response = self.client.policies.begin_create_or_update_by_customer_at_billing_account(
            billing_account_name="str",
            customer_name="str",
            parameters={
                "id": "str",
                "name": "str",
                "properties": {
                    "viewCharges": "str",
                    "policies": [{"name": "str", "policyType": "str", "scope": "str", "value": "str"}],
                    "provisioningState": "str",
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2024-04-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_by_billing_account(self, resource_group):
        response = self.client.policies.get_by_billing_account(
            billing_account_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_or_update_by_billing_account(self, resource_group):
        response = self.client.policies.begin_create_or_update_by_billing_account(
            billing_account_name="str",
            parameters={
                "id": "str",
                "name": "str",
                "properties": {
                    "enterpriseAgreementPolicies": {
                        "accountOwnerViewCharges": "str",
                        "authenticationType": "str",
                        "departmentAdminViewCharges": "str",
                    },
                    "marketplacePurchases": "str",
                    "policies": [{"name": "str", "policyType": "str", "scope": "str", "value": "str"}],
                    "provisioningState": "str",
                    "reservationPurchases": "str",
                    "savingsPlanPurchases": "str",
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2024-04-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_by_subscription(self, resource_group):
        response = self.client.policies.get_by_subscription(
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...
